package it.unibo.tw0708.client;

import it.unibo.tw0708.dao.DAOFactory;
import it.unibo.tw0708.dao.UserDAO;
import it.unibo.tw0708.dao.UserDTO;

import java.util.Collection;

public class InitDB {

	public static final int DEFAULT_DB = DAOFactory.HSQLDB;
	
	public static void main(String[] args) {
		
		// Scelta del database da usare: default o da argomenti
		int db = DEFAULT_DB;
		if ( args != null && args.length > 0 ) {
			try {
				if ( args[0].equalsIgnoreCase("mysql") )
					db = DAOFactory.MYSQL;
				else if ( args[0].equalsIgnoreCase("hsqldb") )
					db = DAOFactory.HSQLDB;
			}
			catch (Exception e) {
				System.out.println("Vabbe', ci abbiamo provato... usiamo HSQLDB");
			}
		}
		
		// Ottenimento dell'oggetto DAO con cui accedere al db
		UserDAO uDAO = DAOFactory.getDAOFactory(db).getUserDAO();
		
		// Verifica che il db non sia gia' stato inizializzato
		System.out.print("Trying to create user's table.... ");
		System.out.print("" + uDAO.createTable() );
		System.out.println();
		Collection<UserDTO> users = uDAO.getUsers(); 
		if ( users.size() > 0 ) {
			System.out.println("Database already holds " + users.size() + " users.");
			printUsers(users);
			System.out.println("Exiting.");
			return;
		}
		
		// Preparazione dei dati (via DTO) da scrivere sul db
		UserDTO u1 = new UserDTO();
		u1.setName("Mario");
		u1.setSurname("Rossi");
		u1.setAddress("viale del tramonto 1, Bologna");
		u1.setMatriculation((long)123456789);
		u1.setNick("SuXmario");
		u1.setPassword("xxx".getBytes());
		// ...e...
		UserDTO u2 = new UserDTO();
		u2.setName("Paolo");
		u2.setSurname("Bianchi");
		u2.setAddress("via col vento 2, Bologna");
		u2.setMatriculation((long)123456789+1);
		u2.setNick("pablito");
		u2.setPassword("yyy".getBytes());
		
		// Scrittura dei dati DTO via DAO
		uDAO.createUser(u1);
		uDAO.createUser(u2);

		// Stampa a video del contenuto del db
		users = uDAO.getUsers(); 
		System.out.println("Database now holds " + users.size() + " users.");
		printUsers(users);
		System.out.println("Done.");
		
	}

	private static void printUsers(Collection<UserDTO> users) {
		System.out.println("---------------------------");
		for ( UserDTO user : users ) {
			System.out.println(user.toString());
		}
		System.out.println("---------------------------");
	}

}
