package it.unibo.tw0809.test;

import static org.junit.Assert.*;
import it.unibo.tw0708.dao.DAOFactory;
import it.unibo.tw0708.dao.UserDAO;
import it.unibo.tw0708.dao.UserDTO;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class UserDAOHsqldb {

	public UserDAO userDAO = null;

	public UserDTO userDTO = null;

	@Before
	public void createTable() {
		userDAO = DAOFactory.getDAOFactory(DAOFactory.HSQLDB).getUserDAO();
		userDAO.createTable();
		//
		userDTO = new UserDTO();
		userDTO.setName("Mario");
		userDTO.setSurname("Rossi");
		userDTO.setAddress("viale del tramonto 1, Bologna");
		userDTO.setMatriculation((long)123456789);
		userDTO.setNick("SuXmario");
		userDTO.setPassword("xxx".getBytes());	
	}

	@After
	public void dropTable() {
		userDAO.dropTable();
		userDAO = null;
		userDTO = null;
	}

	// --------

	@Test
	public void testReadNoUsers() {
		assertEquals("No users in the beginning",0,userDAO.getUsers().size());
	}

	@Test
	public void testCreateAndReadUser() {
		int userDTO_id = userDAO.createUser(userDTO);
		assertTrue("Created users get non negative id",userDTO_id >= 0);
		assertEquals("One user written to the database",1,userDAO.getUsers().size());
		assertTrue("Created users are read correctly",userDTO.equals(userDAO.readUser(userDTO_id)));
	}

	@Test
	public void testUpdateUser() {
		int userDTO_id = userDAO.createUser(userDTO);
		// la update accetta un intero DTO che deve essere già sul db! dobbiamo aggiungere l'id anche nel dato che abbiamo noi!
		userDTO.setId(userDTO_id);
		userDTO.setAddress("Via vai");
		userDTO.setMatriculation(987654321);
		userDTO.setName("NuovoNome");
		userDTO.setSurname("NuovoCognome");
		userDTO.setNick("Nolte");
		userDTO.setPassword("zz".getBytes());
		assertTrue("Update user was successful",userDAO.updateUser(userDTO));
		assertTrue("Update verification was ok too",userDTO.equals(userDAO.readUser(userDTO_id)));
	}

	@Test
	public void testDeleteUser() {
		int userDTO_id = userDAO.createUser(userDTO);
		// la delete accetta un intero DTO, non solo l'id! quindi dobbiamo recuperare il DTO intero prima!
		UserDTO userDTO_to_delete = userDAO.readUser(userDTO_id);
		assertTrue("Correct deletion returns boolean result true",userDAO.deleteUser(userDTO_to_delete));
		assertEquals("No users left",0,userDAO.getUsers().size());
	}

	@Test
	public void testFindUser() {
		int userDTO_id = userDAO.createUser(userDTO);
		// affinché il confronto abbia successo dobbiamo aggiungere l'id anche nel dato che abbiamo noi!
		userDTO.setId(userDTO_id);
		assertTrue("Find user works properly",userDTO.equals(userDAO.findUser("SuXmario")));
	}

	@Test
	public void testGetUsers() {
		fail("Not yet implemented");
	}

}
